@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """
 :mod:`gwosc.api` provides the low-level interface functions
@@ -237,19 +223,20 @@ def _fetch_allevents_event_json(
     """
     allevents = fetch_allevents_json(full=full, host=host)["events"]
     matched = []
-    for dset, metadata in allevents.items():
-        name = metadata["commonName"]
-        if event not in {dset, name}:
-            continue
-        thisversion = metadata["version"]
-        if version is not None and thisversion != version:
-            continue
-        thiscatalog = metadata["catalog.shortName"]
-        if catalog is not None and thiscatalog != catalog:
-            continue
-        matched.append((dset, thisversion, metadata))
+
+    def _match(keyvalue):
+        dset, metadata = keyvalue
+        if event not in {dset, metadata["commonName"]}:
+            return
+        if version is not None and metadata["version"] != version:
+            return
+        if catalog is not None and metadata["catalog.shortName"] != catalog:
+            return
+        return True
+
+    matched = list(filter(_match, allevents.items()))
     if matched:
-        key, _, meta = sorted(matched, key=lambda x: x[1])[-1]
+        key, meta = sorted(matched, key=lambda x: x[1]["version"])[-1]
         return {"events": {key: meta}}
 
     # raise error with the right message
