@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """
 `gwosc.datasets` includes functions to query for available datasets.
@@ -58,6 +44,7 @@ __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 _IGNORE = {
     "tenyear",
     "history",
+    "oldhistory",
 }
 
 
@@ -96,7 +83,7 @@ def _match_event_dataset(
         host=api.DEFAULT_URL,
 ):
     # get strain file list (matching catalog and version)
-    full = True if (detector or segment) else False
+    full = bool(detector or segment)
     try:
         meta = _event_metadata(
             dataset,
@@ -112,7 +99,8 @@ def _match_event_dataset(
         return True
     try:
         strain = meta["strain"]
-    except KeyError:  # no strain file list for this dataset
+    except KeyError:  # pragma: no cover
+        # no strain file list for this dataset
         return False
 
     # match detector
@@ -204,35 +192,32 @@ def _iter_datasets(
     if match:
         reg = re.compile(match)
 
-    def _matched(iter_):
+    def _yield_matches(iter_):
         for x in iter_:
             if not match or reg.search(x):
                 yield x
 
     # search for events and datasets
-    if needruns:
-        for name in _matched(_run_datasets(
+    for needthis, collection in (
+        (needruns, _run_datasets(
             detector=detector,
             host=host,
             segment=segment,
-        )):
-            yield name
-
-    if needcatalogs:
-        for name in _matched(_catalog_datasets(
+        )),
+        (needcatalogs, _catalog_datasets(
             host=host,
-        )):
-            yield name
-
-    if needevents:
-        for name in _matched(_event_datasets(
+        )),
+        (needevents, _event_datasets(
             detector=detector,
             segment=segment,
             host=host,
             version=version,
             catalog=catalog,
-        )):
-            yield name
+        )),
+    ):
+        if not needthis:
+            continue
+        yield from _yield_matches(collection)
 
 
 def find_datasets(
@@ -404,7 +389,7 @@ def event_segment(
         host=host,
     )
 
-    if not data["strain"]:
+    if not data["strain"]:  # pragma: no cover
         raise ValueError(
             "event '{}' has no strain files".format(event),
         )
