@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """Tests for :mod:`gwosc.api`
 """
@@ -47,9 +33,7 @@ def test_fetch_json():
     assert isinstance(out, dict)
     assert len(out['events']) == 3
     assert sorted(out['events']['GW150914-v1']['detectors']) == ['H1', 'L1']
-    assert set(out['runs'].keys()).issubset(
-        {'tenyear', 'O1', 'O1_16KHZ', 'history'},
-    )
+    assert {'tenyear', 'O1', 'O1_16KHZ', 'history'}.issubset(set(out['runs']))
 
     # check errors (use legit URL that isn't JSON)
     url2 = os.path.dirname(os.path.dirname(url))
@@ -76,7 +60,7 @@ def test_fetch_dataset_json():
     end = 934100000
     out = api.fetch_dataset_json(start, end)
     assert not out['events']
-    assert set(out['runs'].keys()).issubset({'tenyear', 'S6', 'history'})
+    assert {"tenyear", "S6", "history"}.issubset(set(out['runs']))
 
 
 @mock.patch('gwosc.api.fetch_json')
