@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """Utilities for URL handling
 """
@@ -110,16 +96,17 @@ def _match_url(
         request
     """
     reg = URL_REGEX.match(basename(url)).groupdict()
-    if (
-            (detector and reg['ifo'] != detector) or
-            (tag and reg['tag'] != tag) or
-            (version and int(reg['version']) != version) or
-            (sample_rate and
-             float(reg["samp"].rstrip("KHZ")) * 1024 != sample_rate) or
-            (duration and float(reg["dur"]) != duration) or
-            (ext and reg["ext"] != ext)
+    for param, regvar in (
+        (detector, reg['ifo']),
+        (tag, reg['tag']),
+        (version, int(reg['version'])),
+        (sample_rate, float(reg["samp"].rstrip("KHZ")) * 1024),
+        (duration, float(reg["dur"]) != duration),
+        (ext, reg["ext"] != ext),
     ):
-        return
+        # if param was given and the regex value doesn't match, ignore this url
+        if param and regvar != param:
+            return
 
     # match times
     if end is not None:
